
---

Okay. I think 1. don't save the toolcall_delta -- this is expensive and not relevant for our non-interaactive experiment runner. But too, add a 'util' sub command with a 'repair-session-files` sub command on it that will fix all experiments with the deltas to reduce file size. Be very sure this won't damage the session files. 

---

- What does `--no-session` do?
- Is the saved json file the same kind pi would need to resume a session?
- Can I also drop the thinking deltas?

---

Pi session

Check out experiments/0046 in /home/generativist/Projects/sota/fashion-mnist

It says running but it clearly completed nad was evaluated. What happeend.